OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "\"config\" 디렉터리에 기록할 수 없습니다!",
    "This can usually be fixed by giving the web server write access to the config directory." : "config 디렉터리에 웹 서버 쓰기 권한을 부여해서 해결할 수 있습니다",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "config.php를 읽기 전용으로 유지하고자 하는 경우, \"config_is_read_only\" 옵션을 true로 설정하십시오.",
    "See %s" : "%s 보기",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "애플리케이션 %1$s이(가) 존재하지 않거나 이 서버와 호환되지 않는 버전입니다. 앱 디렉토리를 확인하십시오.",
    "Sample configuration detected" : "예제 설정 감지됨",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "예제 설정이 복사된 것 같습니다. 올바르게 작동하지 않을 수도 있기 때문에 지원되지 않습니다. config.php를 변경하기 전 문서를 읽어 보십시오",
    "The page could not be found on the server." : "페이지를 서버에서 찾을 수 없습니다.",
    "Email verification" : "이메일 인증",
    "Click the following button to confirm your email." : "아래 버튼을 클릭해 이메일을 인증하십시오.",
    "Click the following link to confirm your email." : "아래 링크를 클릭해 이메일을 인증하십시오.",
    "Confirm your email" : "이메일 인증",
    "Other activities" : "다른 활동",
    "%1$s and %2$s" : "%1$s 및 %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s 및 %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s 및 %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s 및 %5$s",
    "Enterprise bundle" : "엔터프라이즈 번들",
    "Groupware bundle" : "그룹웨어 번들",
    "Hub bundle" : "Hub 번들",
    "Social sharing bundle" : "소셜 공유 번들",
    "PHP %s or higher is required." : "PHP 버전 %s 이상이 필요합니다.",
    "PHP with a version lower than %s is required." : "PHP 버전 %s 미만이 필요합니다.",
    "%sbit or higher PHP required." : "%s비트 이상의 PHP가 필요합니다.",
    "The following architectures are supported: %s" : "다음 아키텍쳐를 지원합니다: %s",
    "The following databases are supported: %s" : "다음 데이터베이스를 지원합니다: %s",
    "The command line tool %s could not be found" : "명령행 도구 %s을(를) 찾을 수 없습니다",
    "The library %s is not available." : "%s 라이브러리를 사용할 수 없습니다.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "%1$s 라이브러리의 버전 %2$s 이상이 필요합니다. 사용 가능한 버전은 %3$s입니다.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "%1$s 라이브러리의 버전 %2$s 이상이 필요합니다. 사용 가능한 버전은 %3$s입니다.",
    "The following platforms are supported: %s" : "다음 플랫폼을 지원합니다: %s",
    "Server version %s or higher is required." : "서버 버전 %s 이상이 필요합니다.",
    "Server version %s or lower is required." : "서버 버전 %s 미만이 필요합니다.",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "로그인된 계정이 관리자, 부 관리자, 또는 이 설정에 접근할 수 있는 권한을 부여받은 계정이어야 합니다",
    "Logged in account must be an admin or sub admin" : "로그인된 계정이 관리자 또는 부 관리자여야 합니다",
    "Logged in account must be an admin" : "로그인된 계정이 관리자여야 합니다",
    "Wiping of device %s has started" : "디바이스 %s의 완전 삭제가 시작되었습니다.",
    "Wiping of device »%s« has started" : "디바이스 »%s«의 완전 삭제가 시작되었습니다.",
    "»%s« started remote wipe" : "»%s«에서 원격 제거를 시작했습니다",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "기기 또는 앱 »%s«에서 원격 제거 과정을 시작했습니다. 작업이 완료될 경우 추가로 이메일을 발송합니다.",
    "Wiping of device %s has finished" : "기기 %s의 완전 제거가 완료됨",
    "Wiping of device »%s« has finished" : "기기 »%s«의 완전 제거가 완료됨",
    "»%s« finished remote wipe" : "»%s«이(가) 원격 제거를 완료함",
    "Device or application »%s« has finished the remote wipe process." : "기기 또는 앱 »%s«이(가) 원격 제거 작업을 완료했습니다.",
    "Remote wipe started" : "원격 제거가 시작됨",
    "A remote wipe was started on device %s" : "원격 제거가 기기 %s에서 시작됨",
    "Remote wipe finished" : "원격 제거가 완료됨",
    "The remote wipe on %s has finished" : "%s에서의 원격 제거가 완료됨",
    "Authentication" : "인증",
    "Unknown filetype" : "알 수 없는 파일 형식",
    "Invalid image" : "잘못된 사진",
    "Avatar image is not square" : "아바타 사진이 정사각형이 아님",
    "Files" : "파일",
    "View profile" : "프로필 보기",
    "Local time: %s" : "현지 시간: %s",
    "today" : "오늘",
    "tomorrow" : "내일",
    "yesterday" : "어제",
    "_in %n day_::_in %n days_" : ["%n일 후"],
    "_%n day ago_::_%n days ago_" : ["%n일 전"],
    "next month" : "다음 달",
    "last month" : "지난 달",
    "_in %n month_::_in %n months_" : ["%n개월 후"],
    "_%n month ago_::_%n months ago_" : ["%n개월 전 "],
    "next year" : "내년",
    "last year" : "작년",
    "_in %n year_::_in %n years_" : ["%n년 후"],
    "_%n year ago_::_%n years ago_" : ["%n년 전"],
    "_in %n hour_::_in %n hours_" : ["%n시간 후"],
    "_%n hour ago_::_%n hours ago_" : ["%n시간 전"],
    "_in %n minute_::_in %n minutes_" : ["%n분 후"],
    "_%n minute ago_::_%n minutes ago_" : ["%n분 전"],
    "in a few seconds" : "몇 초 후",
    "seconds ago" : "초 전",
    "Empty file" : "빈 파일",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "ID: %s인 모듈이 존재하지 않습니다. 앱 설정에서 확인하거나 시스템 관리자에게 연락하십시오.",
    "Dot files are not allowed" : "점으로 시작하는 파일은 허용되지 않음",
    "File already exists" : "파일이 이미 있습니다.",
    "Invalid path" : "잘못된 경로",
    "Failed to create file from template" : "템플릿으로 새 파일을 만들 수 없음",
    "Templates" : "템플릿",
    "Filename contains at least one invalid character" : "파일 이름에 잘못된 글자가 한 자 이상 있음",
    "Empty filename is not allowed" : "파일 이름을 비워 둘 수 없음",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "appinfo 파일을 읽을 수 없어서 앱 \"%s\"을(를) 설치할 수 없습니다.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "이 서버 버전과 호환되지 않아서 앱 \"%s\"을(를) 설치할 수 없습니다",
    "__language_name__" : "한국어",
    "This is an automatically sent email, please do not reply." : "자동으로 전송한 이메일입니다. 답장하지 마십시오.",
    "Appearance and accessibility" : "외형과 접근성",
    "Apps" : "앱",
    "Personal settings" : "개인 설정",
    "Administration settings" : "관리자 설정",
    "Settings" : "설정",
    "Log out" : "로그아웃",
    "Accounts" : "계정",
    "Email" : "이메일",
    "Mail %s" : "%s에게 메일 보내기",
    "Fediverse" : "Fediverse",
    "View %s on the fediverse" : "Fediverse에서 %s 보기",
    "Phone" : "전화 번호",
    "Call %s" : "%s에게 전화하기",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Twitter에서 %s 보기",
    "Website" : "웹 사이트",
    "Visit %s" : "%s 방문하기",
    "Address" : "주소",
    "Profile picture" : "프로필 사진",
    "About" : "정보",
    "Display name" : "표시 이름",
    "Headline" : "표제",
    "Organization" : "개인 정보 관리",
    "Role" : "직책",
    "Unknown account" : "알 수 없는 계정",
    "Additional settings" : "고급 설정",
    "Enter the database name for %s" : "%s에 대한 데이터베이스 이름을 입력하십시오",
    "You cannot use dots in the database name %s" : "데이터베이스 이름에 점(.)을 사용할 수 없습니다 %s",
    "You need to enter details of an existing account." : "존재하는 계정 정보를 입력해야 합니다.",
    "Oracle connection could not be established" : "Oracle 연결을 수립할 수 없습니다.",
    "For the best results, please consider using a GNU/Linux server instead." : "더 좋은 결과를 얻으려면 GNU/Linux 서버를 사용하는 것을 권장합니다.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "%s 인스턴스가 32비트 PHP 환경에서 실행 중이고 php.ini에 open_basedir이 설정되어 있습니다. 4GB 이상의 파일 처리에 문제가 생길 수 있으므로 추천하지 않습니다.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "php.ini의 open_basedir 설정을 삭제하거나 64비트 PHP로 전환하십시오.",
    "Set an admin password." : "관리자의 암호를 설정합니다.",
    "Cannot create or write into the data directory %s" : "데이터 디렉토리 %s을(를) 만들거나 쓰기 작업을 할 수 없음",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "공유 백엔드 %s에서 OCP\\Share_Backend 인터페이스를 구현해야 함",
    "Sharing backend %s not found" : "공유 백엔드 %s을(를) 찾을 수 없음",
    "Sharing backend for %s not found" : "%s의 공유 백엔드를 찾을 수 없음",
    "%1$s via %2$s" : "%1$s(%2$s 경유)",
    "Unknown share type" : "알 수 없는 공유 형식",
    "You are not allowed to share %s" : "%s을(를) 공유할 수 있는 권한이 없습니다",
    "Cannot increase permissions of %s" : "%s의 권한을 늘릴 수 없습니다.",
    "Files cannot be shared with delete permissions" : "파일을 삭제 권한으로 공유할 수 없습니다",
    "Files cannot be shared with create permissions" : "파일을 생성 권한으로 공유할 수 없습니다",
    "Expiration date is in the past" : "만료 날짜가 과거입니다",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["만료 날짜는 최대 %s일까지 설정할 수 있습니다"],
    "Sharing is only allowed with group members" : "같은 그룹 사용자에게만 공유할 수 있습니다",
    "Sharing %s failed, because this item is already shared with the account %s" : "%s을(를) 공유할 수 없습니다. 이 항목을 이미 %s 계정과 공유하고 있습니다",
    "The requested share does not exist anymore" : "요청한 공유가 더 이상 존재하지 않습니다",
    "The requested share comes from a disabled user" : "요청한 공유가 비활성화된 사용자로부터 수신되었습니다",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "사용자 수 제한에 도달하여 사용자를 만들 수 없습니다. 더 자세한 정보는 알림을 참조하십시오.",
    "Could not find category \"%s\"" : "분류 \"%s\"을(를) 찾을 수 없습니다",
    "Input text" : "텍스트를 입력",
    "Sunday" : "일요일",
    "Monday" : "월요일",
    "Tuesday" : "화요일",
    "Wednesday" : "수요일",
    "Thursday" : "목요일",
    "Friday" : "금요일",
    "Saturday" : "토요일",
    "Sun." : "일",
    "Mon." : "월",
    "Tue." : "화",
    "Wed." : "수",
    "Thu." : "목",
    "Fri." : "금",
    "Sat." : "토",
    "Su" : "일",
    "Mo" : "월",
    "Tu" : "화",
    "We" : "수",
    "Th" : "목",
    "Fr" : "금",
    "Sa" : "토",
    "January" : "1월",
    "February" : "2월",
    "March" : "3월",
    "April" : "4월",
    "May" : "5월",
    "June" : "6월",
    "July" : "7월",
    "August" : "8월",
    "September" : "9월",
    "October" : "10월",
    "November" : "11월",
    "December" : "12월",
    "Jan." : "1월",
    "Feb." : "2월",
    "Mar." : "3월",
    "Apr." : "4월",
    "May." : "5월",
    "Jun." : "6월",
    "Jul." : "7월",
    "Aug." : "8월",
    "Sep." : "9월",
    "Oct." : "10월",
    "Nov." : "11월",
    "Dec." : "12월",
    "A valid password must be provided" : "올바른 암호를 입력해야 합니다",
    "Could not create account" : "계정을 만들 수 없음",
    "Account disabled" : "계정이 비활성화됨",
    "Login canceled by app" : "앱에서 로그인 취소함",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "앱 \"%1$s\"이(가) 다음 의존성을 만족하지 않아 설치될 수 없습니다: %2$s",
    "a safe home for all your data" : "내 모든 데이터의 안전한 저장소",
    "Application is not enabled" : "앱이 활성화되지 않았습니다",
    "Authentication error" : "인증 오류",
    "Token expired. Please reload page." : "토큰이 만료되었습니다. 페이지를 새로 고치십시오.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "데이터베이스 드라이버(sqlite, mysql, postgresql)가 설치되지 않았습니다.",
    "Cannot write into \"config\" directory." : "\"config\" 디렉토리에 기록할 수 없습니다",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "config 디렉터리에 웹 서버의 쓰기 권한을 부여해서 해결할 수 있습니다. %s을(를) 참조하십시오",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "config.php 파일을 읽기 전용으로 하시려는 경우, 설정의 \"config_is_read_only\"를 true로 하십시오. %s를 참조하십시오.",
    "Cannot create \"data\" directory." : "\"data\" 디렉토리를 만들 수 없음",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "루트 디렉토리에 웹 서버의 쓰기 권한을 부여해서 해결할 수 있습니다. %s 을(를) 참조하십시오",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "루트 디렉토리에 웹 서버의 쓰기 권한을 부여해서 권한 문제를 해결할 수 있습니다. %s을(를) 참조하십시오.",
    "Your data directory is not writable." : "서버의 데이터 디렉토리에 쓰기 작업을 할 수 없습니다.",
    "Setting locale to %s failed." : "지역을 %s(으)로 설정할 수 없음",
    "Please install one of these locales on your system and restart your web server." : "다음 중 하나 이상의 로캘을 시스템에 설치하고 웹 서버를 다시 시작하십시오.",
    "PHP module %s not installed." : "PHP 모듈 %s이(가) 설치되지 않았습니다.",
    "Please ask your server administrator to install the module." : "서버 관리자에게 모듈 설치를 요청하십시오.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP 설정 \"%s\"이(가) \"%s\"(으)로 설정되어 있지 않습니다.",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "php.ini 파일에서 설정을 변경하면 Nextcloud가 다시 실행됩니다",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP에서 인라인 문서 블록을 삭제하도록 설정되어 있습니다. 일부 코어 앱을 사용하지 못할 수도 있습니다.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Zend OPcache, eAccelerator 같은 캐시/가속기 문제일 수도 있습니다.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP 모듈이 설치되었지만 여전히 없는 것으로 나타납니까?",
    "Please ask your server administrator to restart the web server." : "서버 관리자에게 웹 서버 재시작을 요청하십시오.",
    "The required %s config variable is not configured in the config.php file." : "필수 설정 변수 %s이(가) config.php 파일에서 설정되지 않았습니다.",
    "Please ask your server administrator to check the Nextcloud configuration." : "서버 관리자에게 Nextcloud 설정에 대한 확인을 요청하십시오.",
    "Your data directory must be an absolute path." : "데이터 디렉토리는 절대경로여야 합니다.",
    "Check the value of \"datadirectory\" in your configuration." : "설정에서 \"datadirectory\"의 값을 확인하십시오.",
    "Your data directory is invalid." : "데이터 디렉토리가 올바르지 않습니다.",
    "Action \"%s\" not supported or implemented." : "동작 \"%s\"을(를) 지원하지 않거나 사용할 수 없습니다. ",
    "Authentication failed, wrong token or provider ID given" : "인증이 실패하였습니다. 토큰이나 프로바이더 ID가 틀렸습니다.",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "요청을 완료하기 위한 매개변수가 누락되었습니다. 누락된 매개변수: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\"은(는) 클라우드 연합 제공자 \"%2$s\"이(가) 이미 사용 중입니다.",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "ID가 \"%s\"인 클라우드 연합 제공자가 없습니다.",
    "Could not obtain lock type %d on \"%s\"." : "잠금 형식 %d을(를) \"%s\"에 대해 얻을 수 없습니다.",
    "Storage unauthorized. %s" : "저장소가 인증되지 않았습니다. %s",
    "Storage incomplete configuration. %s" : "저장소 설정이 완전하지 않습니다. %s",
    "Storage connection error. %s" : "저장소 연결 오류입니다. %s",
    "Storage is temporarily not available" : "저장소를 임시로 사용할 수 없음",
    "Storage connection timeout. %s" : "저장소 연결 시간이 초과되었습니다. %s",
    "Images" : "이미지",
    "Question" : "질문",
    "Generated response" : "생성된 응답",
    "Transcribe audio" : "받아적기",
    "Audio input" : "음성 입력",
    "Confirmation" : "확인",
    "Context write" : "글 쓰기",
    "Writes text in a given style based on the provided source material." : "제공된 소스 자료를 기반으로 특정 스타일로 텍스트를 작성합니다.",
    "Writing style" : "쓰기 스타일",
    "Demonstrate a writing style that you would like to immitate" : "흉내내고 싶은 쓰기 스타일 보여주기",
    "Source material" : "소스 자료",
    "The content that would like to be rewritten in the new writing style" : "새로운 쓰기 스타일로 다시 쓰고 싶은 내용",
    "Generated text" : "생성된 텍스트",
    "Optical character recognition" : "광학 문자 인식 (OCR)",
    "Generate image" : "이미지 생성",
    "Prompt" : "프롬프트",
    "Change Tone" : "톤을 변경",
    "Write a text that you want the assistant to rewrite in another tone." : "어시스턴트에 다른 톤으로 다시 쓰고 싶은 텍스트를 쓰기",
    "Desired tone" : "희망하는 톤",
    "In which tone should your text be rewritten?" : "텍스트를 어떤 어조로 다시 씁니까?",
    "The rewritten text in the desired tone, written by the assistant:" : "원하는 톤으로 어시스턴트에 의해서 다시 쓴 텍스트:",
    "Chat" : "대화",
    "Generates a possible headline for a text." : "내용에 대한 헤드라인을 생성하십시오.",
    "Text" : "텍스트",
    "Summarize" : "요약",
    "Summarizes a text" : "텍스트 요약",
    "The original text to summarize" : "요약할 원문",
    "Summary" : "요약",
    "The generated summary" : "생성된 요약",
    "Extract topics" : "주제 추출",
    "Extracts topics from a text and outputs them separated by commas" : "텍스트에서 주제를 추출하고 쉼표로 구분하여 출력",
    "The original text to extract topics from" : "주제를 추출할 원문",
    "Topics" : "주제",
    "The list of extracted topics" : "추출된 주제 목록",
    "Translate" : "번역",
    "Translate text from one language to another" : "다른 언어로 텍스트 번역",
    "Origin text" : "원문",
    "The text to translate" : "번역할 텍스트",
    "Origin language" : "원래 언어",
    "The language of the origin text" : "원문의 언어",
    "Target language" : "목표 언어",
    "The desired language to translate the origin text in" : "원문을 번역하고 싶은 언어",
    "Result" : "결과",
    "The translated text" : "번역된 텍스트",
    "Free prompt" : "자유로운 프롬프트",
    "Runs an arbitrary prompt through the language model." : "언어모델을 통한 임의의 프롬프트 실행",
    "Generate headline" : "헤드라인 생성",
    "Summarizes text by reducing its length without losing key information." : "중요 정보로 내용을 축약하십시오.",
    "Extracts topics from a text and outputs them separated by commas." : "내용에서 주요 주제를 추출하고 쉼표로 이를 구분하십시오.",
    "Organisation" : "조직",
    "Login is too long" : "로그인이 너무 김",
    "Cannot write into \"apps\" directory." : "\"apps\" 디렉터리에 기록할 수 없습니다",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "apps 디렉토리에 웹 서버의 쓰기 권한을 부여하거나 설정 파일에서 앱 스토어를 비활성화하면 해결됩니다.",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "현재 <code>mbstring.func_overload</code>가 <code>%s</code>(으)로 설정되어 있으나, 올바른 값은 <code>0</code>입니다.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "이 문제를 해결하려면 php.ini 에서 <code>mbstring.func_overload</code>를 <code>0</code>으로 설정하십시오."
},
"nplurals=1; plural=0;");
